@@ -1,40 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
-**
 ** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this
+** file. Please review the following information to ensure the GNU Lesser
+** General Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** Alternatively, this file may be used under the terms of the GNU General
+** Public License version 3.0 as published by the Free Software Foundation
+** and appearing in the file LICENSE.GPL included in the packaging of this
+** file. Please review the following information to ensure the GNU General
+** Public License version 3.0 requirements will be met:
+** http://www.gnu.org/copyleft/gpl.html.
+**
+** Other Usage
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
+**
+**
+**
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -58,6 +58,11 @@
 #include <stdarg.h>
 #include <string.h>
 
+#ifndef QT_NO_EXCEPTIONS
+#  include <string>
+#  include <exception>
+#endif
+
 #if !defined(Q_OS_WINCE)
 #  include <errno.h>
 #  if defined(Q_CC_MSVC)
@@ -69,7 +74,7 @@
 #  include <envLib.h>
 #endif
 
-#if defined(Q_CC_MWERKS) && defined(Q_OS_MACX)
+#if defined(Q_OS_MACX) && !defined(QT_NO_CORESERVICES)
 #include <CoreServices/CoreServices.h>
 #endif
 
@@ -81,7 +86,7 @@
 # include "private/qcore_symbian_p.h"
 
 _LIT(qt_S60Filter, "Series60v?.*.sis");
-_LIT(qt_S60SystemInstallDir, "z:\\system\\install\\");
+_LIT(qt_symbianSystemInstallDir, "z:\\system\\install\\");
 #endif
 
 QT_BEGIN_NAMESPACE
@@ -1168,6 +1173,7 @@ bool qSharedBuild()
     \value MV_10_4     Mac OS X 10.4
     \value MV_10_5     Mac OS X 10.5
     \value MV_10_6     Mac OS X 10.6
+    \value MV_10_7     Mac OS X 10.7
     \value MV_Unknown  An unknown and currently unsupported platform
 
     \value MV_CHEETAH  Apple codename for MV_10_0
@@ -1177,6 +1183,7 @@ bool qSharedBuild()
     \value MV_TIGER    Apple codename for MV_10_4
     \value MV_LEOPARD  Apple codename for MV_10_5
     \value MV_SNOWLEOPARD  Apple codename for MV_10_6
+    \value MV_LION     Apple codename for MV_10_7
 
     \sa WinVersion, SymbianVersion
 */
@@ -1192,10 +1199,12 @@ bool qSharedBuild()
     \value SV_9_2 Symbian OS v9.2
     \value SV_9_3 Symbian OS v9.3
     \value SV_9_4 Symbian OS v9.4
-    \value SV_SF_1 Symbian^1
+    \value SV_SF_1 S60 5th Edition (Symbian^1)
     \value SV_SF_2 Symbian^2
-    \value SV_SF_3 Symbian^3
-    \value SV_SF_4 Symbian^4
+    \value SV_SF_3 Symbian^3 or Symbian Anna
+    \value SV_SF_4 \e{This enum value is deprecated.}
+    \value SV_API_5_3 Symbian/S60 API version 5.3 release
+    \value SV_API_5_4 Symbian/S60 API version 5.4 release
     \value SV_Unknown An unknown and currently unsupported platform
 
     \sa S60Version, WinVersion, MacVersion
@@ -1212,8 +1221,10 @@ bool qSharedBuild()
     \value SV_S60_3_1 S60 3rd Edition Feature Pack 1
     \value SV_S60_3_2 S60 3rd Edition Feature Pack 2
     \value SV_S60_5_0 S60 5th Edition
-    \value SV_S60_5_1 S60 5th Edition Feature Pack 1
-    \value SV_S60_5_2 S60 5th Edition Feature Pack 2
+    \value SV_S60_5_1 \e{This enum value is deprecated.}
+    \value SV_S60_5_2 Symbian^3 and Symbian Anna
+    \value SV_S60_5_3 Symbian/S60 API version 5.3 release
+    \value SV_S60_5_4 Symbian/S60 API version 5.4 release
     \value SV_S60_Unknown An unknown and currently unsupported platform
     \omitvalue SV_S60_None
 
@@ -1226,7 +1237,7 @@ bool qSharedBuild()
 
     Defined on Mac OS X.
 
-    \sa Q_WS_WIN, Q_WS_X11, Q_WS_QWS, Q_WS_S60
+    \sa Q_WS_WIN, Q_WS_X11, Q_WS_QWS, Q_WS_QPA, Q_WS_S60
 */
 
 /*!
@@ -1235,7 +1246,7 @@ bool qSharedBuild()
 
     Defined on Windows.
 
-    \sa Q_WS_MAC, Q_WS_X11, Q_WS_QWS, Q_WS_S60
+    \sa Q_WS_MAC, Q_WS_X11, Q_WS_QWS, Q_WS_QPA, Q_WS_S60
 */
 
 /*!
@@ -1244,7 +1255,7 @@ bool qSharedBuild()
 
     Defined on X11.
 
-    \sa Q_WS_MAC, Q_WS_WIN, Q_WS_QWS, Q_WS_S60
+    \sa Q_WS_MAC, Q_WS_WIN, Q_WS_QWS, Q_WS_QPA, Q_WS_S60
 */
 
 /*!
@@ -1253,7 +1264,16 @@ bool qSharedBuild()
 
     Defined on Qt for Embedded Linux.
 
-    \sa Q_WS_MAC, Q_WS_WIN, Q_WS_X11, Q_WS_S60
+    \sa Q_WS_MAC, Q_WS_WIN, Q_WS_X11, Q_WS_QPA, Q_WS_S60
+*/
+
+/*!
+    \macro Q_WS_QPA
+    \relates <QtGlobal>
+
+    Defined on Qt for Embedded Linux, Lite version.
+
+    \sa Q_WS_MAC, Q_WS_WIN, Q_WS_X11, Q_WS_QWS, Q_WS_S60
 */
 
 /*!
@@ -1617,7 +1637,7 @@ bool qSharedBuild()
   \macro Q_WS_S60
   \relates <QtGlobal>
 
-  Defined on S60.
+  Defined on S60 with the Avkon UI framework.
 
   \sa Q_WS_MAC, Q_WS_WIN, Q_WS_X11, Q_WS_QWS
  */
@@ -1635,62 +1655,14 @@ QT_BEGIN_INCLUDE_NAMESPACE
 #include "qnamespace.h"
 QT_END_INCLUDE_NAMESPACE
 
-Q_CORE_EXPORT OSErr qt_mac_create_fsref(const QString &file, FSRef *fsref)
-{
-    return FSPathMakeRef(reinterpret_cast<const UInt8 *>(file.toUtf8().constData()), fsref, 0);
-}
-
-// Don't use this function, it won't work in 10.5 (Leopard) and up
-Q_CORE_EXPORT OSErr qt_mac_create_fsspec(const QString &file, FSSpec *spec)
-{
-    FSRef fsref;
-    OSErr ret = qt_mac_create_fsref(file, &fsref);
-    if (ret == noErr)
-        ret = FSGetCatalogInfo(&fsref, kFSCatInfoNone, 0, 0, spec, 0);
-    return ret;
-}
-
-Q_CORE_EXPORT void qt_mac_to_pascal_string(QString s, Str255 str, TextEncoding encoding=0, int len=-1)
-{
-    if(len == -1)
-        len = s.length();
-#if 0
-    UnicodeMapping mapping;
-    mapping.unicodeEncoding = CreateTextEncoding(kTextEncodingUnicodeDefault,
-                                                 kTextEncodingDefaultVariant,
-                                                 kUnicode16BitFormat);
-    mapping.otherEncoding = (encoding ? encoding : );
-    mapping.mappingVersion = kUnicodeUseLatestMapping;
-
-    UnicodeToTextInfo info;
-    OSStatus err = CreateUnicodeToTextInfo(&mapping, &info);
-    if(err != noErr) {
-        qDebug("Qt: internal: Unable to create pascal string '%s'::%d [%ld]",
-               s.left(len).latin1(), (int)encoding, err);
-        return;
-    }
-    const int unilen = len * 2;
-    const UniChar *unibuf = (UniChar *)s.unicode();
-    ConvertFromUnicodeToPString(info, unilen, unibuf, str);
-    DisposeUnicodeToTextInfo(&info);
-#else
-    Q_UNUSED(encoding);
-    CFStringGetPascalString(QCFString(s), str, 256, CFStringGetSystemEncoding());
-#endif
-}
-
-Q_CORE_EXPORT QString qt_mac_from_pascal_string(const Str255 pstr) {
-    return QCFString(CFStringCreateWithPascalString(0, pstr, CFStringGetSystemEncoding()));
-}
-
-
-
 static QSysInfo::MacVersion macVersion()
 {
+#ifndef QT_NO_CORESERVICES
     SInt32 gestalt_version;
     if (Gestalt(gestaltSystemVersion, &gestalt_version) == noErr) {
         return QSysInfo::MacVersion(((gestalt_version & 0x00F0) >> 4) + 2);
     }
+#endif
     return QSysInfo::MV_Unknown;
 }
 const QSysInfo::MacVersion QSysInfo::MacintoshVersion = macVersion();
@@ -1720,7 +1692,7 @@ QSysInfo::WinVersion QSysInfo::windowsVersion()
     if (winver)
         return winver;
     winver = QSysInfo::WV_NT;
-    OSVERSIONINFOW osver;
+    OSVERSIONINFO osver;
     osver.dwOSVersionInfoSize = sizeof(osver);
     GetVersionEx(&osver);
 #ifdef Q_OS_WINCE
@@ -1808,89 +1780,105 @@ const QSysInfo::WinVersion QSysInfo::WindowsVersion = QSysInfo::windowsVersion()
 #endif
 
 #ifdef Q_OS_SYMBIAN
-# ifdef Q_WS_S60
+static QSysInfo::SymbianVersion cachedSymbianVersion = QSysInfo::SymbianVersion(-1);
 static QSysInfo::S60Version cachedS60Version = QSysInfo::S60Version(-1);
 
-QSysInfo::S60Version QSysInfo::s60Version()
+static void symbianInitVersions()
 {
-    if (cachedS60Version != -1)
-        return cachedS60Version;
-
     // Use pure Symbian code, because if done using QDir, there will be a call back
     // to this method, resulting doing this expensive operation twice before the cache kicks in.
     // Pure Symbian code also makes this method ~10x faster, speeding up the application launch.
     RFs rfs = qt_s60GetRFs();
     TFindFile fileFinder(rfs);
     CDir* contents;
-    TInt err = fileFinder.FindWildByDir(qt_S60Filter, qt_S60SystemInstallDir, contents);
+
+    // Check for platform version
+    TInt err = fileFinder.FindWildByDir(qt_S60Filter, qt_symbianSystemInstallDir, contents);
     if (err == KErrNone) {
+        QScopedPointer<CDir> contentsDeleter(contents);
         err = contents->Sort(EDescending|ESortByName);
         if (err == KErrNone && contents->Count() > 0 && (*contents)[0].iName.Length() >= 12) {
             TInt major = (*contents)[0].iName[9] - '0';
             TInt minor = (*contents)[0].iName[11] - '0';
             if (major == 3) {
                 if (minor == 1) {
-                    return cachedS60Version = SV_S60_3_1;
+                    cachedS60Version = QSysInfo::SV_S60_3_1;
+                    cachedSymbianVersion = QSysInfo::SV_9_2;
                 } else if (minor == 2) {
-                    return cachedS60Version = SV_S60_3_2;
+                    cachedS60Version = QSysInfo::SV_S60_3_2;
+                    cachedSymbianVersion = QSysInfo::SV_9_3;
                 }
             } else if (major == 5) {
                 if (minor == 0) {
-                    return cachedS60Version = SV_S60_5_0;
-                }
-                else if (minor == 1) {
-                    return cachedS60Version = SV_S60_5_1;
-                }
-                else if (minor == 2) {
-                    return cachedS60Version = SV_S60_5_2;
+                    cachedS60Version = QSysInfo::SV_S60_5_0;
+                    cachedSymbianVersion = QSysInfo::SV_9_4;
+                } else if (minor == 1) {
+                    cachedS60Version = QSysInfo::SV_S60_5_1;
+                    cachedSymbianVersion = QSysInfo::SV_SF_2;
+                } else if (minor == 2) {
+                    cachedS60Version = QSysInfo::SV_S60_5_2;
+                    cachedSymbianVersion = QSysInfo::SV_SF_3;
+                } else if (minor == 3) {
+                    cachedS60Version = QSysInfo::SV_S60_5_3;
+                    cachedSymbianVersion = QSysInfo::SV_API_5_3;
+                } else if (minor >= 4) {
+                    cachedS60Version = QSysInfo::SV_S60_5_4;
+                    cachedSymbianVersion = QSysInfo::SV_API_5_4;
                 }
             }
         }
-        delete contents;
     }
 
 #  ifdef Q_CC_NOKIAX86
-    // Some emulator environments may not contain the version specific .sis files, so
-    // simply hardcode the version on those environments.
+    if (cachedS60Version == -1) {
+        // Some emulator environments may not contain the version specific .sis files, so
+        // simply hardcode the version on those environments. Note that can't use
+        // S60_VERSION_* defines for S60 3.x/5.0 platforms, as they do not define them
+        // right anyway in case .sis files are not found.
 #   if defined(__SERIES60_31__)
-    return cachedS60Version = SV_S60_3_1;
+        cachedS60Version = QSysInfo::SV_S60_3_1;
+        cachedSymbianVersion = QSysInfo::SV_9_2;
 #   elif defined(__S60_32__)
-    return cachedS60Version = SV_S60_3_2;
+        cachedS60Version = QSysInfo::SV_S60_3_2;
+        cachedSymbianVersion = QSysInfo::SV_9_3;
 #   elif defined(__S60_50__)
-    return cachedS60Version = SV_S60_5_0;
+        cachedS60Version = QSysInfo::SV_S60_5_0;
+        cachedSymbianVersion = QSysInfo::SV_9_4;
+#   elif defined(S60_VERSION_5_2)
+        cachedS60Version = QSysInfo::SV_S60_5_2;
+        cachedSymbianVersion = QSysInfo::SV_SF_3;
+#   elif defined(S60_VERSION_5_3)
+        cachedS60Version = QSysInfo::SV_S60_5_3;
+        cachedSymbianVersion = QSysInfo::SV_API_5_3;
+#   elif defined(S60_VERSION_5_4)
+        cachedS60Version = QSysInfo::SV_S60_5_4;
+        cachedSymbianVersion = QSysInfo::SV_API_5_4;
 #   endif
-#  endif
-    //If reaching here, it was not possible to determine the version
-    return cachedS60Version = SV_S60_Unknown;
-}
-QSysInfo::SymbianVersion QSysInfo::symbianVersion()
-{
-    switch (s60Version()) {
-    case SV_S60_3_1:
-        return SV_9_2;
-    case SV_S60_3_2:
-        return SV_9_3;
-    case SV_S60_5_0:
-        return SV_9_4;
-    case SV_S60_5_1:
-        return SV_9_4;
-    case SV_S60_5_2:
-        return SV_9_4;
-    default:
-        return SV_Unknown;
     }
-}
-#else
-QSysInfo::S60Version QSysInfo::s60Version()
-{
-    return SV_S60_None;
+#  endif
+
+    if (cachedS60Version == -1) {
+        //If reaching here, it was not possible to determine the version
+        cachedS60Version = QSysInfo::SV_S60_Unknown;
+        cachedSymbianVersion = QSysInfo::SV_Unknown;
+    }
 }
 
 QSysInfo::SymbianVersion QSysInfo::symbianVersion()
 {
-    return SV_Unknown;
+    if (cachedSymbianVersion == -1)
+        symbianInitVersions();
+
+    return cachedSymbianVersion;
+}
+
+QSysInfo::S60Version QSysInfo::s60Version()
+{
+    if (cachedS60Version == -1)
+        symbianInitVersions();
+
+    return cachedS60Version;
 }
-# endif // ifdef Q_WS_S60
 #endif // ifdef Q_OS_SYMBIAN
 
 /*!
@@ -1991,7 +1979,7 @@ QSysInfo::SymbianVersion QSysInfo::symbianVersion()
 */
 void qt_check_pointer(const char *n, int l)
 {
-    qWarning("In file %s, line %d: Out of memory", n, l);
+    qFatal("In file %s, line %d: Out of memory", n, l);
 }
 
 /* \internal
@@ -2066,7 +2054,7 @@ static void mac_default_handler(const char *msg)
 {
     if (qt_is_gui_used) {
         Str255 pmsg;
-        qt_mac_to_pascal_string(msg, pmsg);
+        qt_mac_to_pascal_string(QString::fromAscii(msg), pmsg);
         DebugStr(pmsg);
     } else {
         fprintf(stderr, msg);
@@ -2219,15 +2207,13 @@ void qt_message_output(QtMsgType msgType, const char *buf)
         OutputDebugString(reinterpret_cast<const wchar_t *> (fstr.utf16()));
 #elif defined(Q_OS_SYMBIAN)
         // RDebug::Print has a cap of 256 characters so break it up
-        _LIT(format, "[Qt Message] %S");
-        const int maxBlockSize = 256 - ((const TDesC &)format).Length();
+        char format[] = "[Qt Message] %S";
+        const int maxBlockSize = 256 - sizeof(format);
         const TPtrC8 ptr(reinterpret_cast<const TUint8*>(buf));
-        HBufC* hbuffer = q_check_ptr(HBufC::New(qMin(maxBlockSize, ptr.Length())));
-        for (int i = 0; i < ptr.Length(); i += hbuffer->Length()) {
-            hbuffer->Des().Copy(ptr.Mid(i, qMin(maxBlockSize, ptr.Length()-i)));
-            RDebug::Print(format, hbuffer);
+        for (int i = 0; i < ptr.Length(); i += maxBlockSize) {
+            TPtrC8 part(ptr.Mid(i, qMin(maxBlockSize, ptr.Length()-i)));
+            RDebug::Printf(format, &part);
         }
-        delete hbuffer;
 #else
         fprintf(stderr, "%s\n", buf);
         fflush(stderr);
@@ -2381,7 +2367,7 @@ void qDebug(const char *msg, ...)
     This syntax inserts a space between each item, and
     appends a newline at the end.
 
-    To supress the output at runtime, install your own message handler
+    To suppress the output at runtime, install your own message handler
     with qInstallMsgHandler().
 
     \sa qDebug(), qCritical(), qFatal(), qInstallMsgHandler(),
@@ -2417,7 +2403,7 @@ void qWarning(const char *msg, ...)
     A space is inserted between the items, and a newline is
     appended at the end.
 
-    To supress the output at runtime, install your own message handler
+    To suppress the output at runtime, install your own message handler
     with qInstallMsgHandler().
 
     \sa qDebug(), qWarning(), qFatal(), qInstallMsgHandler(),
@@ -2482,7 +2468,7 @@ void qErrnoWarning(int code, const char *msg, ...)
     Example:
     \snippet doc/src/snippets/code/src_corelib_global_qglobal.cpp 30
 
-    To supress the output at runtime, install your own message handler
+    To suppress the output at runtime, install your own message handler
     with qInstallMsgHandler().
 
     \sa qDebug(), qCritical(), qWarning(), qInstallMsgHandler(),
@@ -2498,6 +2484,19 @@ void qFatal(const char *msg, ...)
 
 // getenv is declared as deprecated in VS2005. This function
 // makes use of the new secure getenv function.
+/*!
+    \relates <QtGlobal>
+
+    Returns the value of the environment variable with name \a
+    varName. To get the variable string, use QByteArray::constData().
+
+    \note qgetenv() was introduced because getenv() from the standard
+    C library was deprecated in VC2005 (and later versions). qgetenv()
+    uses the new replacement function in VC, and calls the standard C
+    library's implementation on all other platforms.
+
+    \sa qputenv()
+*/
 QByteArray qgetenv(const char *varName)
 {
 #if defined(_MSC_VER) && _MSC_VER >= 1400
@@ -2517,6 +2516,20 @@ QByteArray qgetenv(const char *varName)
 #endif
 }
 
+/*!
+    \relates <QtGlobal>
+
+    This function sets the \a value of the environment variable named
+    \a varName. It will create the variable if it does not exist. It
+    returns 0 if the variable could not be set.
+
+    \note qputenv() was introduced because putenv() from the standard
+    C library was deprecated in VC2005 (and later versions). qputenv()
+    uses the replacement function in VC, and calls the standard C
+    library's implementation on all other platforms.
+
+    \sa qgetenv()
+*/
 bool qputenv(const char *varName, const QByteArray& value)
 {
 #if defined(_MSC_VER) && _MSC_VER >= 1400
@@ -2533,7 +2546,7 @@ bool qputenv(const char *varName, const QByteArray& value)
 #endif
 }
 
-#if (defined(Q_OS_UNIX) || defined(Q_OS_WIN)) && !defined(QT_NO_THREAD)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_SYMBIAN) && !defined(QT_NO_THREAD)
 
 #  if defined(Q_OS_INTEGRITY) && defined(__GHS_VERSION_NUMBER) && (__GHS_VERSION_NUMBER < 500)
 // older versions of INTEGRITY used a long instead of a uint for the seed.
@@ -2564,7 +2577,7 @@ Q_GLOBAL_STATIC(SeedStorage, randTLS)  // Thread Local Storage for seed value
 */
 void qsrand(uint seed)
 {
-#if defined(Q_OS_UNIX) && !defined(QT_NO_THREAD) && !defined(Q_OS_SYMBIAN)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_SYMBIAN) && !defined(QT_NO_THREAD)
     SeedStorage *seedStorage = randTLS();
     if (seedStorage) {
         SeedStorageType *pseed = seedStorage->localData();
@@ -2572,10 +2585,10 @@ void qsrand(uint seed)
             seedStorage->setLocalData(pseed = new SeedStorageType);
         *pseed = seed;
     } else {
-        //golbal static seed storage should always exist,
+        //global static seed storage should always exist,
         //except after being deleted by QGlobalStaticDeleter.
         //But since it still can be called from destructor of another
-        //global static object, fallback to sqrand(seed)
+        //global static object, fallback to srand(seed)
         srand(seed);
     }
 #else
@@ -2586,55 +2599,6 @@ void qsrand(uint seed)
 #endif
 }
 
-/*! \internal
-    \relates <QtGlobal>
-    \since 4.6
-
-    Seed the PRNG, but only if it has not already been seeded.
-
-    The default seed is a combination of current time, a stack address and a
-    serial counter (since thread stack addresses are re-used).
-*/
-void qsrand()
-{
-#if (defined(Q_OS_UNIX) || defined(Q_OS_WIN)) && !defined(QT_NO_THREAD)
-    SeedStorage *seedStorage = randTLS();
-    if (seedStorage) {
-        SeedStorageType *pseed = seedStorage->localData();
-        if (pseed) {
-            // already seeded
-            return;
-        }
-        seedStorage->setLocalData(pseed = new SeedStorageType);
-        // start beyond 1 to avoid the sequence reset
-        static QBasicAtomicInt serial = Q_BASIC_ATOMIC_INITIALIZER(2);
-        *pseed = QDateTime::currentDateTime().toTime_t()
-                 + quintptr(&pseed)
-                 + serial.fetchAndAddRelaxed(1);
-#if defined(Q_OS_WIN) || defined(Q_OS_SYMBIAN)
-        // for Windows and Symbian the srand function must still be called.
-        srand(*pseed);
-#endif
-    }
-
-//QT_NO_THREAD implementations
-#else
-    static unsigned int seed = 0;
-
-    if (seed)
-        return;
-
-#if defined(Q_OS_SYMBIAN)
-    seed = Math::Random();
-#elif defined(Q_OS_WIN)
-    seed = GetTickCount();
-#else
-    seed = quintptr(&seed) + QDateTime::currentDateTime().toTime_t();
-#endif
-    srand(seed);
-#endif // defined(Q_OS_UNIX) || defined(Q_OS_WIN)) && !defined(QT_NO_THREAD)
-}
-
 /*!
     \relates <QtGlobal>
     \since 4.2
@@ -2652,7 +2616,7 @@ void qsrand()
 */
 int qrand()
 {
-#if defined(Q_OS_UNIX) && !defined(QT_NO_THREAD) && !defined(Q_OS_SYMBIAN)
+#if defined(Q_OS_UNIX) && !defined(Q_OS_SYMBIAN) && !defined(QT_NO_THREAD)
     SeedStorage *seedStorage = randTLS();
     if (seedStorage) {
         SeedStorageType *pseed = seedStorage->localData();
@@ -2662,10 +2626,10 @@ int qrand()
         }
         return rand_r(pseed);
     } else {
-        //golbal static seed storage should always exist,
+        //global static seed storage should always exist,
         //except after being deleted by QGlobalStaticDeleter.
         //But since it still can be called from destructor of another
-        //global static object, fallback to qrand()
+        //global static object, fallback to rand()
         return rand();
     }
 #else
@@ -2860,6 +2824,40 @@ int qrand()
     \sa qtTrId(), {Internationalization with Qt}
 */
 
+/*!
+    \macro Q_LIKELY(expr)
+    \relates <QtGlobal>
+    \since 4.8
+
+    \brief Hints to the compiler that the enclosed condition, \a expr, is
+    likely to evaluate to \c true.
+
+    Use of this macro can help the compiler to optimize the code.
+
+    Example:
+
+    \snippet doc/src/snippets/code/src_corelib_global_qglobal.cpp qlikely
+
+    \sa Q_UNLIKELY()
+*/
+
+/*!
+    \macro Q_UNLIKELY(expr)
+    \relates <QtGlobal>
+    \since 4.8
+
+    \brief Hints to the compiler that the enclosed condition, \a expr, is
+    likely to evaluate to \c false.
+
+    Use of this macro can help the compiler to optimize the code.
+
+    Example:
+
+    \snippet doc/src/snippets/code/src_corelib_global_qglobal.cpp qunlikely
+
+    \sa Q_LIKELY()
+*/
+
 /*!
     \macro QT_POINTER_SIZE
     \relates <QtGlobal>
@@ -2943,8 +2941,9 @@ int qrand()
     \relates <QtGlobal>
 
     You can use this macro to specify information about a custom type
-    \a Type. With accurate type information, Qt's \l{generic
-    containers} can choose appropriate storage methods and algorithms.
+    \a Type. With accurate type information, Qt's \l{Container Classes}
+    {generic containers} can choose appropriate storage methods and
+    algorithms.
 
     \a Flags can be one of the following:
 
