@@ -1,40 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the tools applications of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in
-** accordance with the Qt Commercial License Agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Nokia.
-**
 ** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this
+** file. Please review the following information to ensure the GNU Lesser
+** General Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
-** rights.  These rights are described in the Nokia Qt LGPL Exception
+** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** Alternatively, this file may be used under the terms of the GNU General
+** Public License version 3.0 as published by the Free Software Foundation
+** and appearing in the file LICENSE.GPL included in the packaging of this
+** file. Please review the following information to ensure the GNU General
+** Public License version 3.0 requirements will be met:
+** http://www.gnu.org/copyleft/gpl.html.
+**
+** Other Usage
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
+**
+**
+**
+**
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -53,17 +53,12 @@
 #include "private/qdbusmetaobject_p.h"
 #include "private/qdbusintrospection_p.h"
 
-#include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef Q_WS_WIN
-#include <process.h>
-#endif
-
 #define PROGRAMNAME     "qdbusxml2cpp"
 #define PROGRAMVERSION  "0.7"
-#define PROGRAMCOPYRIGHT "Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies)."
+#define PROGRAMCOPYRIGHT "Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies)."
 
 #define ANNOTATION_NO_WAIT      "org.freedesktop.DBus.Method.NoReply"
 
@@ -471,11 +466,13 @@ static QString stringify(const QString &data)
     int i;
     for (i = 0; i < data.length(); ++i) {
         retval += QLatin1Char('\"');
-        for ( ; i < data.length() && data[i] != QLatin1Char('\n'); ++i)
+        for ( ; i < data.length() && data[i] != QLatin1Char('\n') && data[i] != QLatin1Char('\r'); ++i)
             if (data[i] == QLatin1Char('\"'))
                 retval += QLatin1String("\\\"");
             else
                 retval += data[i];
+        if (data[i] == QLatin1Char('\r') && data[i+1] == QLatin1Char('\n'))
+            i++;
         retval += QLatin1String("\\n\"\n");
     }
     return retval;
@@ -622,7 +619,7 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
             if (property.access != QDBusIntrospection::Property::Read) {
                 hs << "    inline void " << setter << "(" << constRefArg(type) << "value)" << endl
                    << "    { setProperty(\"" << property.name
-                   << "\", qVariantFromValue(value)); }" << endl;
+                   << "\", QVariant::fromValue(value)); }" << endl;
             }
 
             hs << endl;
@@ -665,7 +662,7 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
             if (!method.inputArgs.isEmpty()) {
                 hs << "        argumentList";
                 for (int argPos = 0; argPos < method.inputArgs.count(); ++argPos)
-                    hs << " << qVariantFromValue(" << argNames.at(argPos) << ')';
+                    hs << " << QVariant::fromValue(" << argNames.at(argPos) << ')';
                 hs << ";" << endl;
             }
 
@@ -698,7 +695,7 @@ static void writeProxy(const QString &filename, const QDBusIntrospection::Interf
                 if (!method.inputArgs.isEmpty()) {
                     hs << "        argumentList";
                     for (argPos = 0; argPos < method.inputArgs.count(); ++argPos)
-                        hs << " << qVariantFromValue(" << argNames.at(argPos) << ')';
+                        hs << " << QVariant::fromValue(" << argNames.at(argPos) << ')';
                     hs << ";" << endl;
                 }
 
@@ -945,7 +942,7 @@ static void writeAdaptor(const QString &filename, const QDBusIntrospection::Inte
                 cs << "void " << className << "::" << setter << "(" << constRefType << "value)" << endl
                    << "{" << endl
                    << "    // set the value of property " << property.name << endl
-                   << "    parent()->setProperty(\"" << property.name << "\", qVariantFromValue(value";
+                   << "    parent()->setProperty(\"" << property.name << "\", QVariant::fromValue(value";
                 if (constRefType.contains(QLatin1String("QDBusVariant")))
                     cs << ".variant()";
                 cs << "));" << endl
@@ -1135,11 +1132,11 @@ int main(int argc, char **argv)
     static code representing those interfaces, which can then be used to make calls to remote
     objects or implement said interfaces.
 
-    \c qdbusxml2dcpp has two modes of operation, that correspond to the two possible outputs it can
+    \c qdbusxml2cpp has two modes of operation, that correspond to the two possible outputs it can
     produce: the interface (proxy) class or the adaptor class. The latter consists of both a C++
     header and a source file, which are meant to be edited and adapted to your needs.
 
-    The \c qdbusxml2dcpp tool is not meant to be run every time you compile your
+    The \c qdbusxml2cpp tool is not meant to be run every time you compile your
     application. Instead, it's meant to be used when developing the code or when the interface
     changes.
 
